=====================
Assets Code Reference
=====================

Models
======

.. automodule:: scarlet.assets.models
    :members:

.. automodule:: scarlet.assets.fields
    :members:

Managers
========

.. automodule:: scarlet.assets.managers
    :members:


Views
=====

.. automodule:: scarlet.assets.views
    :members:


Forms
=====

.. automodule:: scarlet.assets.forms
    :members:
